%define name 		ecell
%define version	 	3.1.105

# when compiling SVN: complete this,
# use %{svn} on line 30, uncomment line 97
%define svn             2632
%define rel		3
%define release 	%mkrel 1.%{svn}.%{rel}

# when compiling stable version
#define rel             1
#define release         %mkrel %{rel}

%define major		2
%define libname		%mklibname %{name}%{major}

%define build_doc 	1

# Macros for in the menu-file.
%define section Applications/Sciences/Biology
%define title   E-cell
%define summary	A software suite for modeling, simulation, and analysis of biological cells

Summary:	%{summary}
Name:		%{name}
Version:	%{version}
Release:	%{release}
# Source0: if stable use %{name}-%{version}.tar.bz2
# if SVN use %{name}-%{version}-%{svn}.tar.bz2
Source0:	%{name}-%{version}-%{svn}.tar.bz2
Source1:	%{name}-icons.tar.bz2
License:	GPL
Group:		Sciences/Biology
Url:		http://ecell.sourceforge.net/
BuildRoot:	%{_tmppath}/%{name}-buildroot
Prefix:		%{_prefix}
Obsoletes:	ecell3 <= 1.0.103
Buildrequires:	python-numpy gnome-python-canvas boost-devel gsl-devel
Requires:	gnome-python gnome-python-canvas gnome-python-gnomevfs pygtk2.0-libglade python-numpy libsbml
Requires:	%{libname} = %{version}-%{release}
# We do not need anymore xorg-x11-Xvfb to be able to import gnome.canvas python module during compilation
BuildRequires:	python-devel python-numpy-devel pygtk2.0-libglade
BuildRequires:  libltdl-devel
BuildRequires:  doxygen
BuildRequires:  docbook-dtd42-xml

%description
E-Cell Project is an international research project aiming to model and
reconstruct biological phenomena in silico, and developing necessary
theoretical supports, technologies and software platforms to allow precise
whole cell simulation.
E-Cell System is an object-oriented software suite for modeling, simulation,
and analysis of large scale complex systems such as biological cells. The
first version of E-Cell Simulation Environment (E-Cell SE) was released
in 1999, after which the development of its Windows version, E-Cell
version 2, had started and recently released. Software development has
since shifted to developing version 3, restructuring the system with
an aim to provide the cell simulation community a common, highly
flexible and high performance software environment.

%package -n %{libname}
Summary:	Libraries from Ecell3
Group:		System/Libraries
Provides:	%{libname} = %{version}-%{release}
Obsoletes:	libecell3_%{major} <= 1.0.103
Requires:	libsbml

%description -n %{libname}
This package provides the libraries and includes files from Ecell3.
Note that development libraries and headers are also included in this
package because they may be required to create new biological processes
or to run the included examples.

# Note : do not create a libecell3-devel package
# (see Note in %{libname} description)

%if %build_doc
%package doc
Summary:	Ecell3 extras documentations
Group:		Sciences/Biology
BuildRequires:  tetex-latex graphviz docbook-utils-pdf

%description doc
E-Cell Project is an international research project aiming to model and
reconstruct biological phenomena in silico, and developing necessary
theoretical supports, technologies and software platforms to allow precise
whole cell simulation.

This package contains extra documentation.
%endif

%prep

%setup -q -n %{name}
%setup -q -n %{name} -T -D -a1 #icons

%build

# SVN version
./autogen.sh
#############

## needed for import gnome.canvas python module
#XDISPLAY=$(i=2; while [ -f /tmp/.X$i-lock ]; do i=$(($i+1)); done; echo $i)
#{_prefix}/X11R6/bin/Xvfb :$XDISPLAY &
#export DISPLAY=:$XDISPLAY
## without it, it will not work ( EE was randomly chosen )
#xauth add $DISPLAY . EE

%configure
%make

# no need, it is not created
# kill $(cat /tmp/.X$XDISPLAY-lock)

# build documentation
%if %build_doc
%make doc
%endif

%install

rm -rf %{buildroot}

%makeinstall
%multiarch_includes $RPM_BUILD_ROOT%{_includedir}/ecell-3.1/ecell_config.h

mkdir -p $RPM_BUILD_ROOT%{_datadir}/applications
cat > $RPM_BUILD_ROOT%{_datadir}/applications/mandriva-%{name}-session-monitor.desktop << EOF
[Desktop Entry]
Name=E-Cell Session Monitor
Comment=A software suite for modeling, simulation, and analysis of biological cells
Exec=%{_bindir}/ecell3-session-monitor
Icon=%{name}
Terminal=false 
Type=Application
Categories=Gtk;Science;Biology;
EOF
cat > $RPM_BUILD_ROOT%{_datadir}/applications/mandriva-%{name}-model-editor.desktop << EOF
[Desktop Entry]
Name=E-Cell Model Editor
Comment=A software suite for modeling, simulation, and analysis of biological cells
Exec=%{_bindir}/ecell3-model-editor
Icon=%{name}
Terminal=false
Type=Application
Categories=Gtk;Science;Biology;
EOF

# icons
%__install -D -m 644 %{name}48.png %{buildroot}/%{_liconsdir}/%{name}.png
%__install -D -m 644 %{name}32.png %{buildroot}/%{_iconsdir}/%{name}.png
%__install -D -m 644 %{name}16.png %{buildroot}/%{_miconsdir}/%{name}.png

rm -fr %buildroot%_datadir/doc/%{name}-%{version}
cp -R ecell/model-editor/doc doc/model-editor

%clean
%__rm -rf %{buildroot}

%post
%{update_menus}

%postun
%{clean_menus}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig


%files -n %{name}
%defattr(0755,root,root,0755)
%{_bindir}/*
%defattr(-,root,root)
%doc AUTHORS COPYING INSTALL NEWS README
#samples (E-Cell examples)
%doc doc/sample/ 
%{_datadir}/ecell-3.1
%{_datadir}/applications/*
%{_iconsdir}/%{name}.png
%{_liconsdir}/%{name}.png
%{_miconsdir}/%{name}.png

%files -n %{libname}
%defattr(-,root,root)
%doc AUTHORS COPYING INSTALL NEWS README
%{_libdir}/ecell-3.1
%{_libdir}/*.so.*
%{_libdir}/python%pyver/site-packages/ecell
# Note: leave dev libraries and includes files in %{libname}
# (see %{libname} description), they are needed for the examples (samples)
%{_libdir}/*.so
%{_libdir}/*.la
%{_includedir}/*

%if %build_doc
%files doc
%defattr(-,root,root)
%doc doc/refman/ doc/users-manual/
%doc doc/model-editor
%doc AUTHORS COPYING INSTALL NEWS README
%endif


%changelog
* Wed Jan 02 2008 Olivier Blin <oblin@mandriva.com> 3.1.105-1.2632.3mdv2008.1
+ Revision: 140723
- restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Sat Sep 01 2007 Funda Wang <fundawang@mandriva.org> 3.1.105-1.2632.3mdv2008.0
+ Revision: 77219
- fix doc files
- fix file list
- drop old menu & fix xdg menu entry comment

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill desktop-file-validate's error: string list key "Categories" in group "Desktop Entry" does not have a semicolon (";") as trailing character
    - kill desktop-file-validate's 'warning: key "Encoding" in group "Desktop Entry" is deprecated'

  + Eric Fernandez <zeb@mandriva.org>
    - fix documentation packaging


* Mon Dec 18 2006 Eric Fernandez <zeb@mandriva.org> 3.1.105-1.2632.2mdv2007.0
+ Revision: 98525
- Added docbook DTD for documentation

* Fri Dec 15 2006 Eric Fernandez <zeb@mandriva.org> 3.1.105-1.2632.1mdv2007.1
+ Revision: 97391
- no doc for the moment (problem with jade)
- make doc-pdf only for the moment (problem with jade)
- BuildRequires doxygen for documentation
- python-devel is also required for x86_64
- python-numpy-devel is required for x86_64
- Import ecell

* Thu Dec 14 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-1.2632.1mdv2007.1
- new snapshot
- removed python-numeric (replaced by python-numpy)

* Sat Sep 02 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-1.2601.1mdv2007.0
- new snapshot
- Buildrequires fix

* Sat Aug 19 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-1.2600.2mdv2007.0
- menu entry fix

* Fri Aug 18 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-1.2600.1mdv2007.0
- new snapshot
- some menu cleaning

* Mon Jul 24 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-1.2597.3mdv2007.0
- correct menu entry missing

* Mon Jul 24 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-1.2597.2mdv2007.0
- correct menu entry

* Sun Jul 23 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-1.2597.1mdv2007.0
- new snapshot
- xdg menu

* Thu Jun 29 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-1.2594.1mdv2007.0
- new snapshot
- xdg menu

* Sun Jun 25 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-1.2592.1mdv2007.0
- new snapshot

* Sat Jun 24 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-1.2589.2mdv2007.0
- requires python-numpy

* Sat Jun 24 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-1.2589.1mdv2007.0
- new snapshot

* Mon Apr 24 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-1.2555.1mdk
- switch to SVN repository
- doc_grouped has been removed from repository
- now compile on x86_64

* Fri Feb 17 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-0.20060216.1mdk
- Use %%{1}mdv2007.1
- New CVS snapshot
- BuildRequires: xorg-x11-Xvfb and set DISPLAY for gnome.canvas import (from Gcompris spec)

* Mon Dec 19 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-0.20051219.1mdk
- New CVS snapshot

* Sat Dec 10 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-0.20051210.2mdk
- New Requires

* Sat Dec 10 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-0.20051210.1mdk
- New CVS snapshot

* Thu Nov 24 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.104-0.20051124.1mdk
- New CVS snapshot

* Tue Nov 08 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.104-0.20051107.1mdk
- Documentation package created
- Spec file cleanup
- New CVS

* Sat Nov 05 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.104-0.20051104.2mdk
- Corrects doc building problem

* Sat Nov 05 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.104-0.20051104.1mdk
- New 3.1.105 snapshot

* Fri Aug 05 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.104-0.20050804.2mdk
- New snapshot, new bug fix

* Sun Jul 31 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.104-0.20050730.1mdk
- New snapshot, corrects a nasty bug in ODEStepper

* Tue Jul 26 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.104-0.20050725.1mdk
- New snapshot
- Clean up Buildrequires (lib devel requirements)

* Thu Mar 03 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.104-0.20050303.1mdk
- New snapshot, CVS version 3.1.104
- multiarch policy

* Wed Jan 19 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.103-0.20050118.1mdk
- New snapshot
- removed --with-plf since graphviz has now a free license and is available in main
- rename ecell3 to ecell, obsoletes ecell3, libecell3
- Happy new year :)

* Mon Dec 20 2004 Eric Fernandez <zeb@zebulon.org.uk> 1.0.103-0.20041219.1mdk
- New snapshot
- libecell3 now requires libsbml

* Thu Dec 09 2004 Eric Fernandez <zeb@zebulon.org.uk> 1.0.103-0.20041208.1mdk
- New snapshot
- some spec comments to clarify the status of documentation and some dev libs

* Sun Dec 05 2004 Michael Scherer <misc@mandrake.org> 1.0.103-0.20040930.3mdk
- Rebuild for new  python

* Fri Oct 29 2004 Olivier Thauvin <thauvin@aerov.jussieu.fr> 1.0.103-0.20040930.2mdk
- Requires lib == version (thx Eric Fernandez <zeb@zebulon.org.uk>)

* Sun Oct 03 2004 Olivier Thauvin <thauvin@aerov.jussieu.fr> 1.0.103-0.20040930.1mdk
- Eric Fernandez <zeb@zebulon.org.uk>
  - spec file cleaning, split package
  - New snapshot, fix script use in GUI (osogo)
- add -with doc and --with plf for documantation

* Wed Sep 22 2004 Michael Scherer <misc@mandrake.org> 1.0.103-0.20040914.1mdk 
- spec files cleaning, and fixing
- from Eric Fernandez <zeb@zebulon.org.uk>
  - New snapshot, various fixes

* Tue Sep 14 2004 Eric Fernandez <zeb@zebulon.org.uk> 1.0.103-0.20040913.1mdk
- New snapshot, fix script use in GUI (osogo)

* Fri Sep 10 2004 Eric Fernandez <zeb@zebulon.org.uk> 1.0.103-0.20040909.1mdk
- New snapshot, various bugfixes

* Thu Sep 09 2004 Eric Fernandez <zeb@zebulon.org.uk> 1.0.103-0.20040908.1mdk
- New snapshot, added LocalSimulatorImplementation

* Wed Sep 01 2004 Eric Fernandez <zeb@zebulon.org.uk> 1.0.103-0.20040830-1mdk
- New snapshot (new model editor and tutorial)

* Fri Aug 27 2004 Eric Fernandez <zeb@zebulon.org.uk> 1.0.103-0.20040825-1mdk
- First mdk release

